Python auto-instr library
*************************

Introduction
------------
- auto-instr is a simple and user-friendly library for automating scientific instruments.
- It offers quick-set functions for configuring and measuring in a single line of code.
- It supports all common bench instruments such as power supply, oscilloscope, function generator, source meter, multimeter,temperature controller etc.

License
-------
- The code is distributed under MIT License.
- You can use auto-instr library in your project without any restrictions.

Supported Python versions
-------------------------
- auto-instr library supports Python 3.


Installation
------------
- Install using ``pip`` (recommended, no separate download required).

   pip install auto-instr

Source code, bug reports, patches
---------------------------------
auto-instr on GitHub:
https://github.com/arvind0790/auto_instr

User manual
-----------
User manual for auto-instr is available online at:
https://auto-instr.readthedocs.io/ 

Changelog
---------
See CHANGES.txt
